a character discription of a distribution, for example
"norm", "t", or "chisq"
q
a vector of quantiles
plot
a logical indicating whether a plot should be created
verbose
a logical
invisible
a logical
digits
the number of digits desired
xlim
x limits
ylim
y limits
vlwd
width of vertical lines
vcol
color of vertical lines
rot
angle for rotating text indicating probability
...
additional arguments, including parameters of the distribution
and additional options for the plot
Value
a vector of probabilities; a plot is printed as a side effect
Details
The most general function is pdist which can work with
any distribution for which a p-function exists. As a convenience, wrappers are
provided for several common distributions.