Use recursion to find a symbolic antiderivative
Attempts symbolic integration of some mathematical/arithmetical forms
Attempts symbolic integration of some mathematical forms
Attempts symbolic integration of some mathematical forms using trigonometric substitution
Takes a call and returns its affine coefficients.
symbolicInt(form, ...)
symbolicAntiD(form, ...)
.intArith(form, ...)
.intMath(form, ...)
.intTrig(form, num, den, .x.)
.affine.exp(tree, .x.)sin, cos, tan, sinh, cosh, tanh, sqrt, and exp.It will not perform more complicated substitutions or integration by parts.