Usage
do(n = 1L, cull = NULL, mode = "default", algorithm = 1,
parallel = TRUE)## S3 method for class 'repeater':
print(x, ...)
## S3 method for class 'repeater,ANY':
*(e1, e2)
Arguments
n
number of times to repeat
cull
function for culling output of objects being repeated. If NULL,
a default culling function is used. The default culling function is
currently aware of objects of types
lme,
lm,
htest,
table
mode
target mode for value returned
algorithm
a number usd to select the algorithm used. Currently numbers below 1
use an older algorithm and numbers >=1 use a newer algorithm which is faster in some
situations.
parallel
a logical indicating whether parallel computation should be attempted
using the parallel package (if it is installed). e1
an object (in cases documented here, the result of running do)
e2
an object (in cases documented here, an expression to be repeated)
x
an object used to select a method.
...
further arguments passed to or from other methods.