read.table, read.csv, and load
to unify and simply reading data from files.read.file(file, header = T, na.strings = c("NA", "", ".", "na", "-"),
comment.char = "#", ...)getwd(.txt and .csv
files, this indicates whether the first line of the file
includes variables names.read.table, read.csv, or
load.file ends in .Rdata, in which
case arbitrary objects may be loaded and a character vector
holding the names of the loaded objects is returned invisibly.read.file uses the file extension to determine how to read
data from the file. If file ends in .Rdata, then
load is used to load the file. If file
ends in .csv, then read.csv is used. Otherwise,
read.table is used.read.table,
read.csv,
load.